References — PolSARtools 0.8 documentation

Skip to main content
`Ctrl`+`K`

# References

References of the research works used in this package.

[1]

R. Barakat. Degree of polarization and the principal idempotents of the coherency matrix. Optics Communications, 23(2):147–150, 1977.

[2]

Jisung Geba Chang, Maxim Shoshany, and Yisok Oh. Polarimetric radar vegetation index for biomass estimation in desert fringe ecosystems. IEEE Transactions on Geoscience and Remote Sensing, 56(12):7102–7108, 2018.

[3]

Subhadip Dey, Avik Bhattacharya, Debanshu Ratha, Dipankar Mandal, and Alejandro C Frery. Target characterization and scattering power decomposition for full and compact polarimetric sar data. IEEE Transactions on Geoscience and Remote Sensing, 2020.

[4]

Y. Kim and J. J. van Zyl. A time-series approach to estimate soil moisture using polarimetric radar data. IEEE Trans. Geosci. Remote Sens., 47(8):2519–2527, 2009. doi:10.1109/TGRS.2009.2014944.

[5]

Vineet Kumar, Dipankar Mandal, Avik Bhattacharya, and YS Rao. Crop characterization using an improved scattering power decomposition technique for compact polarimetric sar data. International Journal of Applied Earth Observation and Geoinformation, 88:102052, 2020.

[6]

Dipankar Mandal, Vineet Kumar, Debanshu Ratha, Subhadip Dey, Avik Bhattacharya, Juan M Lopez-Sanchez, Heather McNairn, and Yalamanchili S Rao. Dual polarimetric radar vegetation index for crop growth monitoring using sentinel-1 sar data. Remote Sensing of Environment, 247:111954, 2020.

[7]

Dipankar Mandal, Debanshu Ratha, Avik Bhattacharya, Vineet Kumar, Heather McNairn, Yalamanchili S Rao, and Alejandro C Frery. A radar vegetation index for crop monitoring using compact polarimetric sar data. IEEE Transactions on Geoscience and Remote Sensing, 2020.

[8]

Debanshu Ratha, Dipankar Mandal, Vineet Kumar, Heather McNairn, Avik Bhattacharya, and Alejandro C Frery. A generalized volume scattering model-based vegetation index from polarimetric sar data. IEEE Geoscience and Remote Sensing Letters, 16(11):1791–1795, 2019.

[9]

M. Trudel and others. Using radarsat-2 polarimetric and envisat-asar dual-polarization data for estimating soil moisture over agricultural fields. Canadian Journal of Remote Sensing, 38(4):514–527, 2012.